@@ -298,7 +298,7 @@ int db_register_ticket(Database* db, Message* ticket)
     d("6\n");
 
     elements = ticket->elements;
-    /* 添付ファイルの登録 */
+    /* register attachment file. */
     foreach (it, elements) {
         Element* e = it->element;
         if (e->is_file) {
@@ -1447,7 +1447,7 @@ List* db_get_burndownchart(Database* db, List* burndowns)
     char sql[DEFAULT_LENGTH];
     sqlite3_stmt *stmt = NULL;
     time_t timer, now;
-    struct tm *date;
+    struct tm date;
     char date_string[24];
     sprintf(sql, 
             "select sum(1), sum(li.close) "
@@ -1462,8 +1462,8 @@ List* db_get_burndownchart(Database* db, List* burndowns)
     now = timer;
     ; /* 30日前 */
     for (timer -= 60 * 60 * 24 * 30; timer <= now; timer += 60 * 60 * 24) {
-        date = localtime(&timer);
-        sprintf(date_string, "%04d-%02d-%02d 23:59:59", date->tm_year + 1900, date->tm_mon + 1, date->tm_mday);
+        localtime_r(&timer, &date);
+        sprintf(date_string, "%04d-%02d-%02d 23:59:59", date.tm_year + 1900, date.tm_mon + 1, date.tm_mday);
         d("time: %s\n", date_string);
 
         sqlite3_reset(stmt);
@@ -1474,7 +1474,7 @@ List* db_get_burndownchart(Database* db, List* burndowns)
             char d[10];
             b->all = sqlite3_column_int(stmt, 0);
             b->not_closed = b->all - sqlite3_column_int(stmt, 1);
-            sprintf(d, "%d", date->tm_mday);
+            sprintf(d, "%d", date.tm_mday);
             string_set(b->day, d);
             list_add(burndowns, b);
         }
